#' econullnetr: tools for using null models to analyse the structure of ecological
#'   networks and identify resource selection
#'
#' econullnetr provides a set of functions for running null models, analysing and
#'   plotting the results, and exporting the outputs for use with other network
#'   packages in R.
#'
#' @references Vaughan, I.P., Gotelli, N.J., Memmott, J., Pearson, C.E.,
#'   Woodward, G. & Symondson, W.O.C. (2018) econullnetr: an R package using null
#'   models to analyse the structure of ecological networks and identify resource
#'   selection. \emph{Methods in Ecology and Evolution}, \strong{9}, 728--733.
#'
#' @name econullnetr
"_PACKAGE"
